@@ -1,7 +1,7 @@
 import pygame
 import time
 import sys
-from __init__ import Window, Object, Colide
+from . import Window, Object, Colide
 # Create the simulation engine
 class Renderer:
     def __init__(self, window, objects, dt=1/60, lenght=2, speed = 1, gravity=False):
